@@ -19,7 +19,7 @@ use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Exif;
 
-$VERSION = '1.32';
+$VERSION = '1.33';
 
 sub ProcessRicohText($$$);
 sub ProcessRicohRMETA($$$);
@@ -1033,11 +1033,7 @@ sub ProcessRicohRMETA($$$)
         my $dat = substr($$dataPt, $pos, $size);
         if ($verbose) {
             $et->VPrint(2, "$$et{INDENT}RMETA section type=$type size=$size\n");
-            if ($verbose > 2) {
-                my %dumpParms = ( Addr => $$dirInfo{DataPos} + $pos, Prefix => $$et{INDENT} );
-                $dumpParms{MaxLen} = 96 if $verbose == 3;
-                Image::ExifTool::HexDump(\$dat, undef, %dumpParms);
-            }
+            $et->VerboseDump(\$dat, Addr => $$dirInfo{DataPos} + $pos);
         }
         if ($type == 1) {                       # section 1: tag names
             # save the tag names
