@@ -14,34 +14,34 @@ use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::XMP;
 use Image::ExifTool::ZIP;
 
-$VERSION = '1.03';
+$VERSION = '1.05';
 
 # test for recognized iWork document extensions and outer XML elements
 my %iWorkType = (
     # file extensions
-    NUMBERS => 'Apple Numbers',
-    PAGES   => 'Apple Pages',
-    KEY     => 'Apple Keynote',
-    KTH     => 'Apple Keynote Theme',
-    NMBTEMPLATE => 'Apple Numbers Template',
+    NUMBERS => 'NUMBERS',
+    PAGES   => 'PAGES',
+    KEY     => 'KEY',
+    KTH     => 'KTH',
+    NMBTEMPLATE => 'NMBTEMPLATE',
     # we don't support double extensions --
     # "PAGES.TEMPLATE" => 'Apple Pages Template',
     # outer XML elements
-    'ls:document' => 'Apple Numbers',
-    'sl:document' => 'Apple Pages',
-    'key:presentation' => 'Apple Keynote',
+    'ls:document' => 'NUMBERS',
+    'sl:document' => 'PAGES',
+    'key:presentation' => 'KEY',
 );
 
 # MIME types for iWork files (Apple has not registered these yet, but these
 # are my best guess after doing some googling.  I'm not 100% sure what "sff"
 # indicates, but I think it refers to the new "flattened" package format)
 my %mimeType = (
-    'Apple Numbers' => 'application/x-iwork-numbers-sffnumbers',
-    'Apple Pages'   => 'application/x-iwork-pages-sffpages',
-    'Apple Keynote' => 'application/x-iWork-keynote-sffkey',
-    'Apple Numbers Template' => 'application/x-iwork-numbers-sfftemplate',
-    'Apple Pages Template'   => 'application/x-iwork-pages-sfftemplate',
-    'Apple Keynote Theme'    => 'application/x-iWork-keynote-sffkth',
+    'NUMBERS'       => 'application/x-iwork-numbers-sffnumbers',
+    'PAGES'         => 'application/x-iwork-pages-sffpages',
+    'KEY'           => 'application/x-iWork-keynote-sffkey',
+    'NMBTEMPLATE'   => 'application/x-iwork-numbers-sfftemplate',
+    'PAGES.TEMPLATE'=> 'application/x-iwork-pages-sfftemplate',
+    'KTH'           => 'application/x-iWork-keynote-sffkth',
 );
 
 # iWork tags
@@ -131,6 +131,12 @@ sub Process_iWork($$)
                     $type = $iWorkType{$1} if $iWorkType{$1};
                 }
             }
+        } else {
+            @members = $zip->membersMatching('(?i)^.*\.(pages|numbers|key)/Index.*');
+            if (@members) {
+                my $tmp = $members[0]->fileName();
+                $type = $iWorkType{uc $1} if $tmp =~ /\.(pages|numbers|key)/i;
+            }
         }
         $type or $type = 'ZIP';     # assume ZIP by default
     }
@@ -148,8 +154,8 @@ sub Process_iWork($$)
         $$et{DOC_NUM} = ++$docNum;
         Image::ExifTool::ZIP::HandleMember($et, $member);
 
-        # process only the index XML and JPEG thumbnail files
-        next unless $file =~ m{^(index\.(xml|apxl)|QuickLook/Thumbnail\.jpg)$}i;
+        # process only the index XML and JPEG thumbnail/preview files
+        next unless $file =~ m{^(index\.(xml|apxl)|QuickLook/Thumbnail\.jpg|[^/]+/preview.jpg)$}i;
         # get the file contents if necessary
         # (CAREFUL! $buff MUST be local since we hand off a value ref to PreviewImage)
         my ($buff, $buffPt);
@@ -208,7 +214,7 @@ information from Apple iWork '09 XML+ZIP files.
 
 =head1 AUTHOR
 
-Copyright 2003-2014, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2018, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
